bayespy.inference.vmp.nodes.gamma.GammaDistribution.compute_message_to_parent
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaDistribution.compute_message_to_parent